@@ -3,8 +3,8 @@ import typing
 from pydantic.error_wrappers import ErrorWrapper
 from pydantic.fields import ModelField
 
+from xpresso._utils.typing import Some
 from xpresso.exceptions import RequestValidationError
-from xpresso.typing import Some
 
 
 def validate_body_field(
